@@ -1,31 +1,29 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #include "filenamehandler.h"
 #include "src/utils/confighandler.h"
+#include "src/utils/strfparse.h"
 #include <QDir>
 #include <QStandardPaths>
 #include <ctime>
+#include <exception>
 #include <locale>
 
+#define SPDLOG_ACTIVE_LEVEL SPDLOG_LEVEL_DEBUG
+#include "spdlog/cfg/env.h"
+#include "spdlog/spdlog.h"
+
 FileNameHandler::FileNameHandler(QObject* parent)
   : QObject(parent)
 {
-    std::locale::global(std::locale(""));
+    try {
+        std::locale::global(std::locale(""));
+    } catch (std::exception& e) {
+        spdlog::error("Locales on your system are not properly configured. "
+                      "Falling back to defaults");
+        std::locale::global(std::locale("en_US.UTF-8"));
+    }
 }
 
 QString FileNameHandler::parsedPattern()
@@ -37,15 +35,16 @@ QString FileNameHandler::parseFilename(const QString& name)
 {
     QString res = name;
     if (name.isEmpty()) {
-        res = QLatin1String("%F_%H-%M");
+        res = ConfigHandler().filenamePatternDefault();
     }
-    std::time_t t = std::time(NULL);
 
-    char* tempData = QStringTocharArr(res);
-    char data[MAX_CHARACTERS] = { 0 };
-    std::strftime(data, sizeof(data), tempData, std::localtime(&t));
-    res = QString::fromLocal8Bit(data, (int)strlen(data));
-    free(tempData);
+    // remove trailing characters '%' in the pattern
+    while (res.endsWith('%')) {
+        res.chop(1);
+    }
+
+    res =
+      QString::fromStdString(strfparse::format_time_string(name.toStdString()));
 
     // add the parsed pattern in a correct format for the filesystem
     res = res.replace(QLatin1String("/"), QStringLiteral("⁄"))
@@ -69,7 +68,7 @@ void FileNameHandler::setPattern(const QString& pattern)
 QString FileNameHandler::absoluteSavePath(QString& directory, QString& filename)
 {
     ConfigHandler config;
-    directory = config.savePathValue();
+    directory = config.savePath();
     if (directory.isEmpty() || !QDir(directory).exists() ||
         !QFileInfo(directory).isWritable()) {
         directory =
@@ -91,7 +90,7 @@ QString FileNameHandler::charArrToQString(const char* c)
     return QString::fromLocal8Bit(c, MAX_CHARACTERS);
 }
 
-char* FileNameHandler::QStringTocharArr(const QString& s)
+char* FileNameHandler::QStringToCharArr(const QString& s)
 {
     QByteArray ba = s.toLocal8Bit();
     return const_cast<char*>(strdup(ba.constData()));
