@@ -1,21 +1,8 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #include "screengrabber.h"
+#include "src/core/qguiappcurrentscreen.h"
 #include "src/utils/filenamehandler.h"
 #include "src/utils/systemnotification.h"
 #include <QApplication>
@@ -25,9 +12,11 @@
 #include <QScreen>
 
 #if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
+#include "request.h"
 #include <QDBusInterface>
 #include <QDBusReply>
 #include <QDir>
+#include <QUuid>
 #endif
 
 ScreenGrabber::ScreenGrabber(QObject* parent)
@@ -37,7 +26,17 @@ ScreenGrabber::ScreenGrabber(QObject* parent)
 QPixmap ScreenGrabber::grabEntireDesktop(bool& ok)
 {
     ok = true;
-#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
+#if defined(Q_OS_MACOS)
+    QScreen* currentScreen = QGuiAppCurrentScreen().currentScreen();
+    QPixmap screenPixmap(
+      currentScreen->grabWindow(QApplication::desktop()->winId(),
+                                currentScreen->geometry().x(),
+                                currentScreen->geometry().y(),
+                                currentScreen->geometry().width(),
+                                currentScreen->geometry().height()));
+    screenPixmap.setDevicePixelRatio(currentScreen->devicePixelRatio());
+    return screenPixmap;
+#elif defined(Q_OS_LINUX) || defined(Q_OS_UNIX)
     if (m_info.waylandDectected()) {
         QPixmap res;
         // handle screenshot based on DE
@@ -77,6 +76,65 @@ QPixmap ScreenGrabber::grabEntireDesktop(bool& ok)
                 }
                 break;
             }
+            case DesktopInfo::SWAY: {
+                QDBusInterface screenshotInterface(
+                  QStringLiteral("org.freedesktop.portal.Desktop"),
+                  QStringLiteral("/org/freedesktop/portal/desktop"),
+                  QStringLiteral("org.freedesktop.portal.Screenshot"));
+
+                // unique token
+                QString token =
+                  QUuid::createUuid().toString().remove('-').remove('{').remove(
+                    '}');
+
+                // premake interface
+                auto* request = new OrgFreedesktopPortalRequestInterface(
+                  QStringLiteral("org.freedesktop.portal.Desktop"),
+                  "/org/freedesktop/portal/desktop/request/" +
+                    QDBusConnection::sessionBus()
+                      .baseService()
+                      .remove(':')
+                      .replace('.', '_') +
+                    "/" + token,
+                  QDBusConnection::sessionBus(),
+                  this);
+
+                QEventLoop loop;
+                const auto gotSignal = [&res, &loop](uint status,
+                                                     const QVariantMap& map) {
+                    if (status == 0) {
+                        QString uri = map.value("uri").toString().remove(0, 7);
+                        res = QPixmap(uri);
+                        res.setDevicePixelRatio(qApp->devicePixelRatio());
+                        QFile imgFile(uri);
+                        imgFile.remove();
+                    }
+                    loop.quit();
+                };
+
+                // prevent racy situations and listen before calling screenshot
+                QMetaObject::Connection conn =
+                  QObject::connect(request,
+                                   &org::freedesktop::portal::Request::Response,
+                                   gotSignal);
+
+                screenshotInterface.call(
+                  QStringLiteral("Screenshot"),
+                  "",
+                  QMap<QString, QVariant>(
+                    { { "handle_token", QVariant(token) },
+                      { "interactive", QVariant(false) } }));
+
+                loop.exec();
+                QObject::disconnect(conn);
+                request->Close().waitForFinished();
+                request->deleteLater();
+
+                if (res.isNull()) {
+                    ok = false;
+                }
+                break;
+            }
             default:
                 ok = false;
                 break;
@@ -87,7 +145,7 @@ QPixmap ScreenGrabber::grabEntireDesktop(bool& ok)
         return res;
     }
 #endif
-
+#if defined(Q_OS_LINUX) || defined(Q_OS_UNIX) || defined(Q_OS_WIN)
     QRect geometry;
     for (QScreen* const screen : QGuiApplication::screens()) {
         QRect scrRect = screen->geometry();
@@ -106,6 +164,7 @@ QPixmap ScreenGrabber::grabEntireDesktop(bool& ok)
     QScreen* screen = QApplication::screens()[screenNumber];
     p.setDevicePixelRatio(screen->devicePixelRatio());
     return p;
+#endif
 }
 
 QPixmap ScreenGrabber::grabScreen(int screenNumber, bool& ok)
@@ -131,7 +190,12 @@ QPixmap ScreenGrabber::grabScreen(int screenNumber, bool& ok)
             p = p.copy(geometry);
         }
     } else {
-        p = QApplication::desktop()->screen(screenNumber)->grab();
+        QScreen* currentScreen = QGuiAppCurrentScreen().currentScreen();
+        p = currentScreen->grabWindow(screenNumber,
+                                      currentScreen->geometry().x(),
+                                      currentScreen->geometry().y(),
+                                      currentScreen->geometry().width(),
+                                      currentScreen->geometry().height());
         ok = true;
     }
     return p;
