@@ -1,21 +1,8 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #include "sidepanelwidget.h"
+#include "src/core/qguiappcurrentscreen.h"
 #include "src/utils/colorutils.h"
 #include "src/utils/pathinfo.h"
 #include <QFormLayout>
@@ -24,6 +11,9 @@
 #include <QPushButton>
 #include <QSlider>
 #include <QVBoxLayout>
+#if defined(Q_OS_MACOS)
+#include <QScreen>
+#endif
 
 class QColorPickingEventFilter : public QObject
 {
@@ -66,6 +56,7 @@ SidePanelWidget::SidePanelWidget(QPixmap* p, QWidget* parent)
 
     QFormLayout* colorForm = new QFormLayout();
     m_thicknessSlider = new QSlider(Qt::Horizontal);
+    m_thicknessSlider->setRange(1, 100);
     m_thicknessSlider->setValue(m_thickness);
     m_colorLabel = new QLabel();
     m_colorLabel->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -74,7 +65,7 @@ SidePanelWidget::SidePanelWidget(QPixmap* p, QWidget* parent)
     m_layout->addLayout(colorForm);
 
     connect(m_thicknessSlider,
-            &QSlider::sliderReleased,
+            &QSlider::valueChanged,
             this,
             &SidePanelWidget::updateCurrentThickness);
     connect(this,
@@ -129,9 +120,9 @@ void SidePanelWidget::updateColorNoWheel(const QColor& c)
       QStringLiteral("QLabel { background-color : %1; }").arg(c.name()));
 }
 
-void SidePanelWidget::updateCurrentThickness()
+void SidePanelWidget::updateCurrentThickness(int value)
 {
-    emit thicknessChanged(m_thicknessSlider->value());
+    emit thicknessChanged(value);
 }
 
 void SidePanelWidget::colorGrabberActivated()
@@ -161,7 +152,19 @@ QColor SidePanelWidget::grabPixmapColor(const QPoint& p)
 {
     QColor c;
     if (m_pixmap) {
+#if defined(Q_OS_MACOS)
+        QScreen* currentScreen = QGuiAppCurrentScreen().currentScreen();
+        QPoint point = p;
+        if (currentScreen) {
+            point = QPoint((p.x() - currentScreen->geometry().x()) *
+                             currentScreen->devicePixelRatio(),
+                           (p.y() - currentScreen->geometry().y()) *
+                             currentScreen->devicePixelRatio());
+        }
+        QPixmap pixel = m_pixmap->copy(QRect(point, point));
+#else
         QPixmap pixel = m_pixmap->copy(QRect(p, p));
+#endif
         c = pixel.toImage().pixel(0, 0);
     }
     return c;
@@ -169,9 +172,7 @@ QColor SidePanelWidget::grabPixmapColor(const QPoint& p)
 
 bool SidePanelWidget::handleKeyPress(QKeyEvent* e)
 {
-    if (e->key() == Qt::Key_Space) {
-        emit togglePanel();
-    } else if (e->key() == Qt::Key_Escape) {
+    if (e->key() == Qt::Key_Escape) {
         releaseColorGrab();
         updateColor(m_colorBackup);
     } else if (e->key() == Qt::Key_Return || e->key() == Qt::Key_Enter) {
