@@ -1,19 +1,5 @@
-// Copyright(c) 2017-2019 Alejandro Sirgo Rica & Contributors
-//
-// This file is part of Flameshot.
-//
-//     Flameshot is free software: you can redistribute it and/or modify
-//     it under the terms of the GNU General Public License as published by
-//     the Free Software Foundation, either version 3 of the License, or
-//     (at your option) any later version.
-//
-//     Flameshot is distributed in the hope that it will be useful,
-//     but WITHOUT ANY WARRANTY; without even the implied warranty of
-//     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-//     GNU General Public License for more details.
-//
-//     You should have received a copy of the GNU General Public License
-//     along with Flameshot.  If not, see <http://www.gnu.org/licenses/>.
+// SPDX-License-Identifier: GPL-3.0-or-later
+// SPDX-FileCopyrightText: 2017-2019 Alejandro Sirgo Rica & Contributors
 
 #pragma once
 
@@ -37,7 +23,7 @@ public:
 
 signals:
     void colorChanged(const QColor& c);
-    void thicknessChanged(const int& t);
+    void thicknessChanged(int t);
     void togglePanel();
 
 public slots:
@@ -46,7 +32,7 @@ public slots:
 
 private slots:
     void updateColorNoWheel(const QColor& c);
-    void updateCurrentThickness();
+    void updateCurrentThickness(int value);
 
 private slots:
     void colorGrabberActivated();
